==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/gl.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Tema de alto contraste",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un tema de alto contraste para facilitar a navegación. A calidade visual será reducida, mais a claridade aumentará.",
    "Dark theme (beta)" : "Tema escuro (beta)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Un tema escuro para descansar a vista reducindo a luminosidade e o brillo. Aínda está en desenvolvemento, así que informe de calquera incidencia que poida atopar.",
    "Dyslexia font" : "Tipo de letra para disléxicos",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic é un tipo de letra libre deseñada para mitigar algúns dos erros comúns de lectura causados pola dislexia.",
    "Accessibility" : "Accesibilidade",
    "Accessibility options for nextcloud" : "Opcións de accesibilidade para o Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Ofrece múltiples opcións de accesibilidade para facilitar o uso do Nextcloud",
    "Web Content Accessibility Guidelines" : "Pautas de accesibilidade ao contido web",
    "our issue tracker" : "o noso seguidor de incidencias",
    "our design team" : "o noso equipo de deseño",
    "Enable" : "Activar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/gl.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Tema de alto contraste",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un tema de alto contraste para facilitar a navegación. A calidade visual será reducida, mais a claridade aumentará.",
    "Dark theme" : "Tema escuro",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Un tema escuro para descansar a vista reducindo a luminosidade e o brillo. Aínda está en desenvolvemento, así que informe de calquera incidencia que poida atopar.",
    "Dyslexia font" : "Tipo de letra para disléxicos",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic é un tipo de letra libre deseñada para mitigar algúns dos erros comúns de lectura causados pola dislexia.",
    "Accessibility" : "Accesibilidade",
    "Accessibility options for nextcloud" : "Opcións de accesibilidade para o Nextcloud",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Ofrece múltiples opcións de accesibilidade para facilitar o uso do Nextcloud",
    "Web Content Accessibility Guidelines" : "Pautas de accesibilidade ao contido web",
    "our issue tracker" : "o noso seguidor de incidencias",
    "our design team" : "o noso equipo de deseño",
    "Enable" : "Activar",
    "Dark theme (beta)" : "Tema escuro (beta)",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia. The typeface was created by Abelardo Gonzalez, who released it through an open-source license." : "OpenDyslexic é un tipo de letra libre deseñada para mitigar algúns dos erros comúns de lectura causados pola dislexia. O tipo de letra foi creado por Abelardo González, quen o publicou mediante unha licenza de código aberto.",
    "Provides multiple accessibilities options to ease your use of nextcloud" : "Ofrece múltiples opcións de accesibilidade para facilitar o uso do Nextcloud",
    "Themes" : "Temas",
    "Fonts" : "Tipos de letra",
    "enabled" : "activado"
},
"nplurals=2; plural=(n != 1);");
